OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
   1. 1 Commercial manned guarding
   2. Ω Πρόσθετοι κίνδυνοι (από το χρήστη)
      1. Ω.1 The entrance floor is often wet
   - Υπό εξέταση κίνδυνος
   - Κίνδυνος σε εκκρεμότητα
   - Ασφαλής κατάσταση
   - Προσοχή κίνδυνος!
4. Σχέδιο Δράσης
5. Έκθεση
6. Παρούσα Κατάσταση 0%

Εάν αναγνωρίσατε κινδύνους που δεν έχουν συμπεριληφθεί στο εργαλείο, μπορείτε να τους προσθέσετε τώρα:

Σημαντικό: Σας συμβουλεύουμε, αν δεν το έχετε κάνει ακόμα, να περιηγηθείτε πρώτα σε όλες τις ενότητες κινδύνων (modules) αυτού του εργαλείου ώστε να αποφευχθεί η εισαγωγή κινδύνων που υπάρχουν ήδη.

Εάν δεν χρειάζεται να προσθέσετε κινδύνους, συνεχίστε.

Προηγούμενο Μετάβαση στο Σχέδιο Δράσης

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More